from setuptools import find_packages, setup

__version__ = "0.22.0"

setup(
    name="CRTL",
    version=__version__,
    description="CRTL: A Library for Concept Recognition, Tagging, and Linking",
    long_description="Here's a placeholder for a long description",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    entry_points={
        "spacy_factories": [
            "trend_ngram_tfidf_span_linker = crtl.components.crtl_el:make_trend_ngram_tfidf_span_linker",
            "trend_ngram_tfidf_entity_linker = crtl.components.crtl_el:make_trend_ngram_tfidf_entity_linker",
            "basic_candidate_selector = crtl.components.crtl_el:make_basic_candidate_selector",
            "trend_literal_link_overrider = crtl.components.link_overrider:make_ent_link_overrider",
            "trend_discrepancy_rectifier = crtl.components.discrepancy_rectifier:make_trend_discrepancy_rectifier",
        ],
        "spacy_scorers": [
            "crtl.score_links = crtl.components.span_linking_scorer:make_linker_scorer",
            "crtl.score_accuracy_at_n = crtl.components.accuracy_at_n:get_accuracy_at_n_scorer",
        ],
        "spacy_readers": [
            "crtl.read_gzipped_jsonl_from_cached_path = crtl.lkb.lkb:make_gzipped_jsonl_from_cache_path_reader",
            "crtl.read_concept_ids_from_json = crtl.components.discrepancy_rectifier:make_high_level_concept_id_reader",
        ],
    },
    install_requires=["tqdm", "requests", "boto3", "spacy", "scipy", "scikit-learn", "networkx"],
    extras_require={
        "develop": ["tox", "black", "mypy", "pre-commit"],
        "trendnet_derive": ["pandas", "neo4j", "networkx"],
        "trendnet_web": ["flask-restful", "flask-cors"],
        "semantic_embedder": ["pytorch"],
        "dual_encoder": [],
        "nmslib": [
            "nmslib@git+https://github.com/nmslib/nmslib@8c4160283caa8576dc53fc3ee43ed350ff2781e5#subdirectory=python_bindings"
        ],
    },
)
